# Data visualization plug-in for Thonny

This is a plug-in for `Thonny IDE <https://thonny.org>`, which adds possibility to 
visualize your data. 

## Installation

1. Install Thonny 3.2 or later
2. Select "Tools => Manage plug-ins"...
3. Enter ``thonny-data-visualization`` to search box and press ENTER
4. Install the plug-in
5. Be sure that you are up to date (upgrade the plug-in at the same place)
6. Restart Thonny

After this you should see Globals and locals variables, Hierarchical data view and Graphical data view in the View menu.

## Usage

More details in the [usage manual](Usage_manual.md)

### Using the globals and locals variables view

1. In the View section, select Globals and locals variables
2. Run or debug your program to see your variables
3. Open the object inspector and see the details of your variables

### Using the hierarchical view

1. In the View section, select Hierarchical data view
2. Run or debug your program
3. Use the + and - buttons to see the hierarchical representation of your different variables

### Using the graphical view

1. In the View section, select Graphical data view
2. Run or debug your program
3. Use the little colored circles to see the links between your variables

- In this view you can move the different blocks and replace them by default with the Align button above
- You can also use the + and - buttons to see or hide details about your variables
- You can use the Extend and Reduce buttons to display or hide the details of all the variables
- You can use the button above on the right to allow the view to show more (or less) informations about your variables, especially the imported ones 